@@ -18,6 +18,7 @@ use crate::rbatis::Rbatis;
 use crate::utils::string_util;
 use futures::executor::block_on;
 use rbatis_core::{DateTimeNative, Format};
+use crate::snowflake::new_snowflake_id;
 
 
 /// must be only one have Some(Value)
@@ -199,12 +200,13 @@ fn bson_arr_to_string(arg: Vec<Bson>) -> (Vec<Bson>, String) {
         _ => {
             (vec![], s)
         }
-    }
+    };
 }
 
 #[async_trait]
 impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
     async fn exec(&mut self, sql: &str, mut args: Vec<bson2::Bson>) -> Result<DBExecResult, Error> {
+        let rb_task_id = new_snowflake_id();
         let mut sql = sql.to_string();
         let is_prepared = args.len() > 0;
         for item in &self.get_rbatis().sql_intercepts {
@@ -213,14 +215,13 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
         if self.get_rbatis().log_plugin.is_enable() {
             let (_args, args_string) = bson_arr_to_string(args);
             args = _args;
-            self.get_rbatis().log_plugin.info(
-                &format!(
-                    "Exec   ==> {}\n{}[rbatis] [{}] Args   ==> {}",
-                    &sql,
-                    string_util::LOG_SPACE,
-                    "",
-                    args_string
-                ),
+            self.get_rbatis().log_plugin.info(rb_task_id,
+                                              &format!(
+                                                  "Exec   ==> {}\n{}[rbatis]                      Args   ==> {}",
+                                                  &sql,
+                                                  string_util::LOG_SPACE,
+                                                  args_string
+                                              ),
             );
         }
         let result;
@@ -228,18 +229,18 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
             let q: DBQuery = self.bind_arg(&self.conn.driver_type(), &sql, args)?;
             result = self.conn.exec_prepare(q).await;
         } else {
-            result = self.conn.exec(&sql).await;
+            result = self.conn.exec_sql(&sql).await;
         }
         if self.get_rbatis().log_plugin.is_enable() {
             match &result {
                 Ok(result) => {
-                    self.get_rbatis().log_plugin.info(
-                        &format!("RowsAffected <== {}", result.rows_affected),
+                    self.get_rbatis().log_plugin.info(rb_task_id,
+                                                      &format!("RowsAffected <== {}", result.rows_affected),
                     );
                 }
                 Err(e) => {
                     self.get_rbatis().log_plugin
-                        .error(&format!("ReturnErr  <== {}", e));
+                        .error(rb_task_id, &format!("ReturnErr  <== {}", e));
                 }
             }
         }
@@ -247,6 +248,7 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
     }
 
     async fn fetch<T>(&mut self, sql: &str, mut args: Vec<bson2::Bson>) -> Result<T, Error> where T: DeserializeOwned {
+        let rb_task_id = new_snowflake_id();
         let mut sql = sql.to_string();
         let is_prepared = args.len() > 0;
         for item in &self.get_rbatis().sql_intercepts {
@@ -255,14 +257,13 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
         if self.get_rbatis().log_plugin.is_enable() {
             let (_args, args_string) = bson_arr_to_string(args);
             args = _args;
-            self.get_rbatis().log_plugin.info(
-                &format!(
-                    "Fetch  ==> {}\n{}[rbatis] [{}] Args   ==> {}",
-                    &sql,
-                    string_util::LOG_SPACE,
-                    "",
-                    args_string
-                ),
+            self.get_rbatis().log_plugin.info(rb_task_id,
+                                              &format!(
+                                                  "Fetch  ==> {}\n{}[rbatis]                      Args   ==> {}",
+                                                  &sql,
+                                                  string_util::LOG_SPACE,
+                                                  args_string
+                                              ),
             );
         }
         if is_prepared {
@@ -272,11 +273,11 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
                 match &result {
                     Ok(result) => {
                         self.get_rbatis().log_plugin
-                            .info(&format!("ReturnRows <== {}", result.1));
+                            .info(rb_task_id, &format!("ReturnRows <== {}", result.1));
                     }
                     Err(e) => {
                         self.get_rbatis().log_plugin
-                            .error(&format!("ReturnErr  <== {}", e));
+                            .error(rb_task_id, &format!("ReturnErr  <== {}", e));
                     }
                 }
             }
@@ -287,11 +288,11 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
                 match &result {
                     Ok(result) => {
                         self.get_rbatis().log_plugin
-                            .info(&format!("ReturnRows <== {}", result.1));
+                            .info(rb_task_id, &format!("ReturnRows <== {}", result.1));
                     }
                     Err(e) => {
                         self.get_rbatis().log_plugin
-                            .error(&format!("ReturnErr  <== {}", e));
+                            .error(rb_task_id, &format!("ReturnErr  <== {}", e));
                     }
                 }
             }
@@ -310,6 +311,7 @@ impl<'a> RBatisConnExecutor<'a> {
     pub async fn begin(self) -> crate::Result<RBatisTxExecutor<'a>> {
         let tx = self.conn.begin().await?;
         return Ok(RBatisTxExecutor {
+            tx_id: new_snowflake_id(),
             conn: tx,
             rb: self.rb,
         });
@@ -318,6 +320,7 @@ impl<'a> RBatisConnExecutor<'a> {
 
 #[derive(Debug)]
 pub struct RBatisTxExecutor<'a> {
+    pub tx_id: i64,
     pub conn: DBTx<'a>,
     pub rb: &'a Rbatis,
 }
@@ -340,14 +343,13 @@ impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
         if self.get_rbatis().log_plugin.is_enable() {
             let (_args, args_string) = bson_arr_to_string(args);
             args = _args;
-            self.get_rbatis().log_plugin.info(
-                &format!(
-                    "Exec   ==> {}\n{}[rbatis] [{}] Args   ==> {}",
-                    &sql,
-                    string_util::LOG_SPACE,
-                    "",
-                    args_string
-                ),
+            self.get_rbatis().log_plugin.info(self.tx_id,
+                                              &format!(
+                                                  "Exec   ==> {}\n{}[rbatis]                      Args   ==> {}",
+                                                  &sql,
+                                                  string_util::LOG_SPACE,
+                                                  args_string
+                                              ),
             );
         }
         let result;
@@ -355,18 +357,18 @@ impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
             let q: DBQuery = self.bind_arg(&self.conn.driver_type, &sql, args)?;
             result = self.conn.exec_prepare(q).await;
         } else {
-            result = self.conn.exec(&sql).await;
+            result = self.conn.exec_sql(&sql).await;
         }
         if self.get_rbatis().log_plugin.is_enable() {
             match &result {
                 Ok(result) => {
-                    self.get_rbatis().log_plugin.info(
-                        &format!("RowsAffected <== {}", result.rows_affected),
+                    self.get_rbatis().log_plugin.info(self.tx_id,
+                                                      &format!("RowsAffected <== {}", result.rows_affected),
                     );
                 }
                 Err(e) => {
                     self.get_rbatis().log_plugin
-                        .error(&format!("ReturnErr  <== {}", e));
+                        .error(self.tx_id, &format!("ReturnErr  <== {}", e));
                 }
             }
         }
@@ -382,14 +384,13 @@ impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
         if self.get_rbatis().log_plugin.is_enable() {
             let (_args, args_string) = bson_arr_to_string(args);
             args = _args;
-            self.get_rbatis().log_plugin.info(
-                &format!(
-                    "Fetch  ==> {}\n{}[rbatis] [{}] Args   ==> {}",
-                    &sql,
-                    string_util::LOG_SPACE,
-                    "",
-                    args_string
-                ),
+            self.get_rbatis().log_plugin.info(self.tx_id,
+                                              &format!(
+                                                  "Fetch  ==> {}\n{}[rbatis]                      Args   ==> {}",
+                                                  &sql,
+                                                  string_util::LOG_SPACE,
+                                                  args_string
+                                              ),
             );
         }
         if is_prepared {
@@ -399,11 +400,11 @@ impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
                 match &result {
                     Ok(result) => {
                         self.get_rbatis().log_plugin
-                            .info(&format!("ReturnRows <== {}", result.1));
+                            .info(self.tx_id, &format!("ReturnRows <== {}", result.1));
                     }
                     Err(e) => {
                         self.get_rbatis().log_plugin
-                            .error(&format!("ReturnErr  <== {}", e));
+                            .error(self.tx_id, &format!("ReturnErr  <== {}", e));
                     }
                 }
             }
@@ -414,11 +415,11 @@ impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
                 match &result {
                     Ok(result) => {
                         self.get_rbatis().log_plugin
-                            .info(&format!("ReturnRows <== {}", result.1));
+                            .info(self.tx_id, &format!("ReturnRows <== {}", result.1));
                     }
                     Err(e) => {
                         self.get_rbatis().log_plugin
-                            .error(&format!("ReturnErr  <== {}", e));
+                            .error(self.tx_id, &format!("ReturnErr  <== {}", e));
                     }
                 }
             }
